@@ -128,7 +128,7 @@ class Crp:
 
         grp = train_df.groupby('customerid')
 
-        grp_dict = {'order_date':'max','id':'count','totalprice':'sum'}
+        grp_dict = {'order_date':'max','id':'count','totalprice':'sum',''}
 
         df_matrix = gb.agg(d).rename(columns={'id':'num_orders'})
 
@@ -230,14 +230,14 @@ class Crp:
         date_flag_min = dateFlag_sep - pd.DateOffset(months=train_window)
         print(dateFlag_sep,date_flag_min)
         # Construct dataframe according to that timeframe
-        output.append(prepareDF(original_dataset,dateFlag_sep,date_flag_min,lag,items_dataset))
+        output.append(self.prepareDF(original_dataset,dateFlag_sep,date_flag_min,lag,items_dataset))
         print(dateFlag_sep,date_flag_min)
         # Repeat the procedure until the bottom limit of the trainFrame reaches the minimum date possible according to the original dataset.
         while date_flag_min >= min_date:
         
             dateFlag_sep = dateFlag_sep - pd.DateOffset(months=lag)
             date_flag_min = dateFlag_sep - pd.DateOffset(months=train_window)
-            output.append(prepareDF(original_dataset,dateFlag_sep,date_flag_min,lag,items_dataset))
+            output.append(self.prepareDF(original_dataset,dateFlag_sep,date_flag_min,lag,items_dataset))
             print(dateFlag_sep,date_flag_min)
             
             
